[−][src]Struct srtp2_sys::srtp_master_key_t
@brief srtp_master_key_t represents a master key. There will be a Master Key Index and the Master Key associated with the Master Key Index. Need to also keep track of the Master Key Index Size to correctly read it from a packet.
Fields
key: *mut c_ucharmki_id: *mut c_ucharmki_size: c_uintTrait Implementations
impl Clone for srtp_master_key_t[src]
fn clone(&self) -> srtp_master_key_t[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
Performs copy-assignment from source. Read more
impl Copy for srtp_master_key_t[src]
impl Debug for srtp_master_key_t[src]